==> jmb.video-0.1.tar.gz: jmb.video-0.1/jmb/video/admin.py <==
# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _


from jmb.core.admin.options import OrderedModelAdmin, ExtendibleModelAdmin
from jmb.core.forms.models import AdminModelForm
from jmb.video.models import AreaVideo,Video


###################################
## ADMIN                          #
###################################

class VideoAdminForm(AdminModelForm):
    class Meta:
        model = Video

class VideoAdmin(ExtendibleModelAdmin, OrderedModelAdmin):
    list_display = ('get_status_icon', 'ordering','titolo','area','file','get_edit_icon', 'get_delete_icon')
    list_display_links = ('titolo',)
    #list_editable =  ('slug',)
    prepopulated_fields = {"slug": ("titolo",)}
    model = Video
    save_on_top = True
    search_fields = ("status", "titolo",)
    date_hierarchy = "date_create"
    list_per_page = 20
    ordering = ("ordering", "titolo",)
    form = VideoAdminForm
    fieldsets = (
        (_('Order'), {
            'fields': ('ordering',),
            'classes': ('collapse',),
            }
        ),
        (_('general admin'), {
            'fields': ('status',),
            }
        ),
        (_("Publication datetime"),{
            'fields':('pub_date_begin','pub_date_end'),
            'classes': ('collapse',),
        }

        ),
        (None, {
            'fields': ('area','titolo','slug',
                     'sottotitolo', 'descrizione', 'thumb',
                     'file', 'autoencode', 'embed_code',
                     )
            }
        ),
    )





#    fieldsets = (
##        (_('logs admin'), {
##            'fields': (
##                'creator', 'date_create', 'last_modifier', 'date_last_modify',
##                ),
##            'classes': (
##                'collapse',
##                )
##        }),
#        (_('visualization admin'), {
#            'fields': ('ordering',),
#            'classes': ('collapse',),
#            }),
#        (_('general admin'), {
#            'fields': ('status',),
#            }),
##        (None,
##         {'fields': ('area_video', 'ordering', 'titolo',
##                     'sottotitolo', 'descrizione', 'thumb',
##                     'file', 'autoencode', 'embed_code',
##                     )}
##        ),
#        (_('SEO Settings'),
#         {'fields': ('page_title','meta_description','meta_keywords',),
#          'classes': ('collapse',)}),
#
#    ),



class AreaVideoAdmin(admin.ModelAdmin):
    prepopulated_fields = {"slug": ("nome",)}
    list_display = ('ordering','nome','slug')
#    list_display_links = ('nome',)
#    prepopulated_fields = {"slug": ("nome",)}
    fieldsets = (

                    (_('Order'), {
                        'fields': ('ordering',),
                        'classes': ('collapse',),
                    }),
                    (_('general admin'), {
                        'fields': ('status',),
                    }),
                    (None,
                     {'fields': ('nome', 'slug',
                         )}
                        ),


                    )



admin.site.register(AreaVideo, AreaVideoAdmin)
admin.site.register(Video, VideoAdmin)

==> jmb.video-0.1.1.tar.gz: jmb.video-0.1.1/jmb/video/admin.py <==
# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _


from jmb.core.admin.options import OrderedModelAdmin, ExtendibleModelAdmin
from jmb.core.forms.models import AdminModelForm
from jmb.video.models import AreaVideo,Video


###################################
## ADMIN                          #
###################################

class VideoAdminForm(AdminModelForm):
    class Meta:
        model = Video

class VideoAdmin(ExtendibleModelAdmin, OrderedModelAdmin):
    list_display = ('get_status_icon', 'ordering','titolo','area','file','get_edit_icon', 'get_delete_icon')
    list_display_links = ('get_edit_icon',)
    #list_editable =  ('slug',)
    prepopulated_fields = {"slug": ("titolo",)}
    model = Video
    save_on_top = True
    search_fields = ("status", "titolo",)
    date_hierarchy = "date_create"
    list_per_page = 20
    ordering = ("ordering", "titolo",)
    form = VideoAdminForm
    fieldsets = (
        (_('Order'), {
            'fields': ('ordering',),
            'classes': ('collapse',),
            }
        ),
        (_('general admin'), {
            'fields': ('status',),
            }
        ),
        (_("Publication datetime"),{
            'fields':('pub_date_begin','pub_date_end'),
            'classes': ('collapse',),
        }

        ),
        (None, {
            'fields': ('area','titolo','slug',
                     'sottotitolo', 'descrizione', 'thumb',
                     'file', 'autoencode', 'embed_code',
                     )
            }
        ),
    )





#    fieldsets = (
##        (_('logs admin'), {
##            'fields': (
##                'creator', 'date_create', 'last_modifier', 'date_last_modify',
##                ),
##            'classes': (
##                'collapse',
##                )
##        }),
#        (_('visualization admin'), {
#            'fields': ('ordering',),
#            'classes': ('collapse',),
#            }),
#        (_('general admin'), {
#            'fields': ('status',),
#            }),
##        (None,
##         {'fields': ('area_video', 'ordering', 'titolo',
##                     'sottotitolo', 'descrizione', 'thumb',
##                     'file', 'autoencode', 'embed_code',
##                     )}
##        ),
#        (_('SEO Settings'),
#         {'fields': ('page_title','meta_description','meta_keywords',),
#          'classes': ('collapse',)}),
#
#    ),



class AreaVideoAdmin(admin.ModelAdmin):
    prepopulated_fields = {"slug": ("nome",)}
    list_display = ('ordering','nome','slug')
#    list_display_links = ('nome',)
#    prepopulated_fields = {"slug": ("nome",)}
    fieldsets = (

                    (_('Order'), {
                        'fields': ('ordering',),
                        'classes': ('collapse',),
                    }),
                    (_('general admin'), {
                        'fields': ('status',),
                    }),
                    (None,
                     {'fields': ('nome', 'slug',
                         )}
                        ),


                    )



admin.site.register(AreaVideo, AreaVideoAdmin)
admin.site.register(Video, VideoAdmin)
